#
# spec file for package numbat
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           numbat
Version:        1.14.0
Release:        1.4
URL:            https://github.com/sharkdp/numbat
Summary:        Statically typed programming language for scientific computations
Group:          Productivity/Scientific/Physics
License:        Apache-2.0 OR MIT
Source0:        https://github.com/sharkdp/numbat/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  zstd

%description
Numbat is a statically typed programming language for scientific computations
with first class support for physical dimensions and units.

%prep
%autosetup -a1

%build
%{cargo_build} --all-features
rm book/.gitignore

%install
pushd numbat-cli
%{cargo_install} --all-features
popd

%check
pushd numbat-cli
%{cargo_test} --all-features
popd

%files
%license LICENSE-MIT LICENSE-APACHE
%doc     README.md book
%{_bindir}/numbat*

%changelog
* Sat Nov 16 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Fix tests in specfile
- Update vendored dependencies
* Sat Oct 26 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 1.14.0:
  * Fix unit_of-related crashes
  * Allow units with rational exponents
  * Add support for highlighting of @example
  * Use '%%' in tutorial
  * Add percentage-calculation functions
  * Merge pull request #608 from sharkdp/add-cdot-operator
  * Add '\cdot' as additional multiplication operator
  * Merge pull request #425 from ValentinLeTallec/master
  * Merge remote-tracking branch 'origin/master' into ValentinLeTallec/master
  * Merge pull request #568 from Goju-Ryu/mixed-units-conversion
  * Replace 'foldl(_add, 0)' by 'sum'
  * Use ′ and ″ as default short names for arcminute/arcsecond
  * Add @example for unit_list
  * Add explicit use statement for non-prelude functions to examples
  * Fixed some clippy warnings
  * Improved error message when encountering a trailing equals sign, adding heuristic to check whether user might have been trying to define a function
  * Removed needless `Product[Into]Iter` types
  * Switched to a for loop (simpler)
  * Added consuming `DType::into_factors`, removing need for mutable access to factors Changed `from_factors` to take an owned `Vec`
  * Removed some code duplication
  * Cleaned up some todos and clippy warnings
  * Merge pull request #566 from Bzero/example_decorator
  * Merge branch 'master' into example_decorator
  * More compact examples
  * Make tests use different values on the right side instead of the left of asserts
  * Shrunk `TokenKind` from 16 bytes to 2 by replacing `IntegerWithBase(usize)` with `IntegerWithBase(u8)` (max base is 16, no way do we exceed 255) Removed Box from base-n digit predicate function by switching to function pointers
  * Improved completion performance Removed non-matching candidates from consideration earlier, obviating need to filter them out Removed clones of candidates that didn't match (before: clone then check; after: check then clone)
  * Comment
  * Replaced many `String`s in `typed_ast::Expression` with `&'a str` (generally anywhere we could borrow from the input)
  * Borrowed name in `typed_ast::Statement::DefineDimension`
  * Borrowed type parameter names in `typed_ast::Statement::DefineFunction`
  * DefineVariable name `String` -> `&'a str`
  * Removed allocations in `typed_ast::Statement::Define*` variants (`String` -> `&'a str`)
  * Corrected swapped epsilon/varepsilon unicode input shortcuts
  * Update documentation
  * Add explicit file encoding to `open` calls
  * Code cleanup reducing clones (in theory)
  * Minor code cleanup
  * Formatting
  * Deduped some code
  * Remove allocations in `Markup` by switching to `Cow<'static, str>` Now strings are only allocated if non-static (The vast majority of markup strings are `&'static`)
  * Plumbed spans through alias definitions, allowing for more precise error messages
  * Add 'tau' alias for 'τ', closes #581
  * Update mixed-unit tests
  * Add comparison with other calculators/languages
  * fix floating point precision problem
  * Replace string based mixed unit functions
  * Add tests and documentation
  * Fix formatting and simplify
  * Potential fix of 0.0 float bug
  * Add `unit_list` function
  * Use variable in funtion to simplify
  * Use variable in funtion to simplify
  * Merge branch 'pr/425_human_format'
  * Reduce clutter in human time
  * Apply example suggestions from code review
  * Fixed two clippy warnings
  * Simplified type
  * More `String`s replaced with `&str`s (#579)
  * Add lowercase alias for EUR
  * Hopefully fixed wasm build error
  * Clone example context instead of re-interpreting
  * Apply suggested example formatting
  * Remove example for the time function
  * Move details closing tag inside conditional
  * Expand documentation by adding examples
  * Automatically add examples to the documentation
  * Add @examples decorator
  * Replaced `ByteIndex::start()` with `ByteIndex(0)` --- now that it's just an index, `0` is clearer than `start` (which made sense when there was other data beyond just the current byte)
  * Renamed `SourceCodePositition` [sic] to `ByteIndex` to make its semantics clearer (it really is just a byte index into a string, nothing more nothing less)
  * Removed `line` and `position` from `SourceCodePositition` [sic] Made it a tuple struct instead; now it is just a wrapper over a byte index This was... surprisingly simple? turns out `line` and `position` weren't used anywhere but tests; they're never surfaced to the user
  * Add lowercase aliases for currency units
  * Dimensionful abs function
  * Update plotly to 0.10
  * Replaced `CommandKind::new` with `impl FromStr for CommandKind` (isomorphic but more self-descriptive)
  * Removed `ls` as alias for command `list` in web version for consistency with CLI Updated web docs
  * Updated cli docs
  * Restored accidentatlly removed alias `?` for `help`
  * Moved `writeln!` arg into format string
  * Replaced boolean `errored` with isomorphic but clearer `Result<(), ()>` and renamed some items accordingly
  * Boxed `NumbatError`
  * Factored out common components of `evaluate_const_expr`
  * boxed the errors to reduce size of `Result<T, BigError>`
  * Moved pushing to session history out of `parse_and_evaluate` and into `run_repl` Therefore changed `parse_and_evalute` to return a struct of `control_flow, errored` to let session history know whether the command in question errored Added tests to `session_history.rs` Code seems overall not terrible now
  * Renamed session history file to history.nbt
  * Simplified history implementation, at the cost of one allocation when reading prelude
  * Moved `session_history` storage from `Cli::repl` into `Cli::repl_loop`
  * Initial, simple implementation of saving per-session history
  * Update to official repo
  * Enable tests to run without internet access
  * Fix WASM tests
  * Consolidated duplicated code in `TypeChecker::elaborate_define_variable` and the `ast::Statement::DefineDerivedUnit` branch of `TypeChecker::elaborate_statement`
  * Removed clone of `ctx.dimension_registry()` (requires an additional `self.context.lock()` as the lock must be dropped to allow `self` to be borrowed in the interm)
  * Fixed inadvertently removed trailing whitespaces whose removal broke tests
  * Fixed a handful of clippy "needless `&` on `&str`" warnings
  * Removed pointless `.into()` on `&'static str` into itself
  * Renamed arg for clarity
  * Fixed semantically incorrect use of `char::len_utf8` (although it was used on a newline and would've had no effect, it is semantically correct to keep the original `+= 1`)
  * Removed `// todo` comment (we did the todo)
  * Replaced the `String` in `Token` with `&'a str` Unfortunately due to borrow checker limitations, this required moving `input` fields out of both `Parser` and `Tokenizer`, as with the immutable borrow in place, there is no way to tell Rust that a mutable borrow won't touch the input So, the input is now an (immutable ref) argument to all the methods that used to refer to `&self.input` And there were a lot... But now `Token` doesn't carry an owned `String` Also shrunk `Tokenizer` by doing all math in terms of byte offsets into its input (using existing `SourceCodePosition` fields) instead of storing a separate `Vec<char>` with char indices
  * Replaced `String` with `&'static str` in `ForeignFunction`
  * Removed unused `CommandParser::set_code_source_id`
  * Removed alias "ls" for "list" command
  * Replaced trailing space characters in two tests with `\x20` to prevent them from being removed when removing trailing whitespace on save
  * Changed `InvalidCommand` to take a `String` instead of `&'static str` Replaced `ensure_zero_args!` macro with function, now that this is possible (since we can use `format!` instead of `concat!)
  * Enum-ified command kind, making it strongly typed (no need for `unreachable!`) Made "list" report incorrect number of args before reporting invalid arg, in the event that both errors were present
  * Fixed bug where `resolver.add_code_source` was run twice per non-command input How: split `CommandParser` into a second struct, `SourcelessCommandParser`, that contains just the input, no `code_source_id` `SourcelessCommandParser` has a fallible initializer that only returns `Some(Self)` if the line is indeed a command (ie starts with a command word) Then we simply check if this initializer succeeded; if so then make a new `code_source_id` and construct the full `CommandParser`, then parse the command
  * Made struct `CommandParser` and reimplemented command parsing in terms of it (much cleaner)
  * Passed `code_source_id` to `parse_command` instead of a `Resolver` Note that there is a bug where non-command inputs run `add_course_source` twice, which leads to incorrect line numbers
  * Fixed clippy warnings
  * Fixed typo: TrivialResultion -> TrivialResolution
  * Added .DS_Store to gitignore
  * Add 3D printing example
  * Reduced some copy-pasted code
  * Continued REPL if `save dst` errored instead of just exiting
  * Tests for Command
  * Added Info command Added some helper functions for commands
  * Implemented commands like `list`, `help`, `save` (new) with more flexible parsing (eg tolerant of arbitrary whitespace) Commands report `ParseError`s if the syntax is invalid (eg too many or not enough args) This required making `Resolver::add_code_source` public and adding `Context::resolver_mut` to track source code positions of commands
  * Added .DS_Store to gitignore
  * Add travel cost example
  * Use noembed feature of plotly.rs
  * Fix typo
  * Update documentation in extra::algorithms
  * Add documentation
  * Add first version of color format conversions
  * Move back to deploy.sh (CI)
  * Move rustc version check from deploy.sh to build.sh
  * Add regression test for #534
  * Add regression test for angle example in #505
  * Remove FullSimplify instruction
  * remove useless simplify call
  * fix warning
  * add a floor_in and round_in function
  * Fix most of the simplify calls
  * reduce the number of calls to simplify
  * Fix typo
  * Add lines-of-code as a unit
  * Type-inference Gauss elimination example
  * Fix pretty printing for some generic types
  * Remove size of typed_ast::Expression from 416 byte to 224 byte
  * Safe versions of round/ceil/floor/trunc
  * Use a MapStack for the environment and namespaces in the typechecker
  * Add a MapStack datastructure for the typechecker
  * Fix warning
  * refactor(numbat): move interpreter.rs and assert_eq_3.rs to interpreter module directory
  * feat(ffi/procedures): assert_eq_3: in error message, print with precision of epsilon
  * tests(interpreter): integration tests for assert_eq/3 failure
  * fix(procedures): assert_eq/3: fail check iff difference is greater than epsilon
  * feat(Quantity): add abs method
  * feat(ffi/procedures): assert_eq/3: better error message using consistent units for comparands
  * fix: formatting in `numbat/src/typechecker/`
  * style: simplify string formatting for readability
  * Add XKCD comics to documentation
  * Use mean earth radius, update XKCD/What-if examples
  * New example: Geographical distance
  * Add fixed-point iteration
  * Fix duplicated word
  * Enable commented out test
  * Minor stylistic change
  * Bump Bytes from yanked version
  * Add '@description' to vscode extension
  * Major documentation update
  * Auto-format JS/CSS files
  * Change syntax to … where … and …, solve remaining tasks
  * Use 'where' clause in existing Numbat code
  * Add new 'where' keyword to Numbat syntaxes
  * fix the parser for most case
  * remove insert_at
  * add an example of local variables
  * add a typechecking test
  * add parser test
  * Make the local definition of variables works in function
  * make the parser support multi-line where
  * update the DefineFunction type to include a local variables array
  * split the statement parsing into multiple function to make it more manageable
  * implement insert_at
  * Move examples, do not execute them during testing
  * Fix tests
  * Fix WASM build
  * Add support for bar charts
  * Rename function
  * Rename module
  * Allow empty lines after postfix apply
  * Change postfix apply to |>
  * Use reverse function application for optional arguments
  * Allow empty lines after postfix apply
  * Change postfix apply to |>
  * Use larger number of points
  * Fix list handling
  * reverse the arguments of cons_end so it fit better with the revers call operator
  * add tests
  * Make the reverse function call operator more powerful
  * Fix doc build
  * Move cons_end test
  * Fix typo
  * simplify slightly the .iter method
  * uses Arc::ptr_eq where possibel
  * Better documentation phrasing
  * rename the advance_view function to tail
  * re-implements head to avoid unecessary Value::clone
  * adds a little bit of module documentation
  * fix bug
  * add more test on lists
  * move the list to another module and improve the cons and cons_end
  * provide an efficient way to push at the end of the list with cons_end
  * make list slightly less embarrassingly slow
  * Calendar arithmetic for DateTimes
  * Fix bug in constraint checker
  * Use TimeZone::to_offset instead of strftime("%%Z")
  * Add volume mount for /usr/share/zoneinfo
  * Better formatting of date times, including time zones
  * Improve parse_datetime, add tests
  * Better error handling
  * Update to jiff 0.1.3, fix WASM version
  * Update to jiff 1.2.1, bring back float. seconds
  * Use link to latest jiff docs
  * Remove TODO comment
  * Display clock times (CET, CEST, ..) instead of only offsets
  * Port from chrono to jiff
  * Merge remote-tracking branch 'origin/master' into plotting
  * use skip_empty_lines instead of redefining it
  * allow newlines between parameters when defining functions
  * allow closing parens and newlines in function call
  * Fix typo
  * Adapt description, remove short versions for now
  * Add description of therm unit in prelude
  * update tests for therm and thermie
  * change unit values
  * run build.py for CI check
  * remove heat energy units in documentation
  * 2 new heat energy units 'therm' and 'thermie' added
  * Add julian_date conversions
  * Add support for Unicode subscript-number input
  * Add mixed-unit conversion functions
  * Add special symbols for arcmin, arcsec
  * Add trunc(…) function
  * Add ord(…) function
  * Document string functions
  * Improved documentation
  * Improved documentation
  * Minor reorganization
  * Remove core page
  * Split list of functions by module
  * Initial work towards autogenerating the list of functions
  * info: Print readable function signatures
  * Update article to latest Numbat version
  * Impact test with new format
  * Change human format to "1156 days + 14 hours + ... (approx. 3 years + 2 months)")
  * Manage negative times
  * Fix error on modules_are_self_consistent
  * Add years and months to human date formatter
  * Add TODO
  * Readable types for partially annotated functions
  * Test more cases
  * Fix recovery after runtime errors
  * Initial work on readable function types
  * Bring back readable types
  * Remove stale autogenerated file
  * Fix mdbook warning
  * Remove workhours example generation
  * Add 'run' button to all examples in documentation
  * Auto-generate a 'run' link for numbat examples
  * Port 'book/build.sh' to python
  * Add source spans for assertion error messages
  * Restructure Numbat integration tests
  * Fix insta warnings
  * Use assert_eq instead of assert(… == …)
  * Implement 'gcd' and 'lcm'
  * Update dependencies
  * Use push_front/pop_front
  * Add short -N flag for --no-prelude
  * Reimplement plot-functionality using plotly
  * Patch https://github.com/rustwasm/wasm-pack/issues/1389
  * Fix and extend paper_size example
  * Allow for newlines after then/else
  * Support string escape sequences
  * Minor adaptations
  * Remove unnecessary cloning in VM
  * Implement sort_by_key
  * Remove trailing character after new line test
  * Allow newlines before closing ] in list expression
  * Add lists with newline parser tests
  * Fix clippy suggestions
  * Split out remaining functions
  * Split out strings, datetime functions
  * Split out list functions
  * Split out math functions
  * Remove assertions
  * Use a macro for FFI functions
  * Split ffi module into multiple files
  * Move ffi to separate module
  * root_newton: Add max. iterations to prevent infinite loop
  * Better error message for empty string interpolations
  * Fix formatting
  * Fix spans for list expressions
  * Fix spans for return type annotations
  * Fix docs number notation
  * Add documentation for element_at
  * Add median
  * Add standard deviation and variance
  * Add simple (and inefficient) merge sort
  * Add take and drop
  * Add str_find, split, join
  * tail: throw user error if list is empty
  * Fix boiling point of tungsten
  * Add relevant matches to typed hole diagnostics
  * Add return type
  * Very basic plotting support
  * Make local timezone support optional
  * Add new HasField constraint to fix field access for yet-unknown types
  * Save full struct type information inside the AccessField AST element
  * Add coloring config argument
  * Add linspace
  * Add typed holes
  * Add Voyager 1 example
  * refactor: have 1 source of truth for height
  * fix: `p.links` shifting
  * fix: layout shifting after terminal loads
  * Add simple numerical methods for root finding and differentiation
  * Change quadratic_equation to return a list of solutions
  * Update lock file
  * Better pretty printing for variable definitions
  * Better pretty printing for unit definitions
  * Update examples
  * Bring back readable-type functionality
  * Bring back printing of function signature in 'info'
  * Remove logging, resolve some TODOs
  * Slightly better error messages for constraint solver / substitution errors
  * Reset deploy script
  * Disable superfluous tests
  * Re-enable interpreter tests
  * Re-implement mean,maximum,minimum using lists
  * Re-introduce error function in strings.nbt
  * Change formulation of diff
  * Active non-dtype list tests
  * Bring back remaining tests
  * Fix bug
  * More inference tests
  * Tests for more operators
  * Add tests for exponentiation
  * Instantiation tests
  * Fix non-dtype lists
  * Add list-type inference tests
  * First batch of type-inference tests
  * Proper error for fn f(x,y) = x^y
  * Fix checking of return type
  * Simplify code
  * Better arity errors for callables
  * Enable one more test
  * Enforce dtype constraint for binary operators
  * Remove irrelevant test
  * Add bounds for fn types
  * Add type parameters to the type 'AST', check missing Dim constraints
  * Add parsing of type parameter bounds
  * Minor improvement in error messages
  * Fix soundness bug for lists
  * Fix equality, improve errors for lists
  * Enable even more tests
  * Proper return-type error reporting, enable more tests
  * Minor
  * Re-enable struct tests
  * Re-enable datetime/human
  * Restore datetime tests
  * Improve error reporting for simple expressions
  * Use polymorphic zero in algebra.nbt
  * Wasm version
  * Change deploy script
  * Remove logging
  * Make NaN and inf polymorphic, too
  * Fix printing type of []
  * Show quantifiers in type schemes
  * Fix warnings
  * Better pretty-printing for types
  * Even more list stuff
  * assert_eq for all types, add more list functions
  * Turn exponents into integers
  * Remove leftover
  * Bring back most example programs
  * Add call-generic-function-from-generic-function test
  * user error tests
  * Comment out failing tests
  * Fix exponentiation tests
  * Fix assert/assert_eq
  * Add new dtype helper
  * Fix callable calls
  * Generic diff function
  * Uncomment statistics functions
  * We have proper lists!
  * Minor
  * Fix unit definitions
  * Initial work on exponentiation
  * Initial work on generic functions
  * Proper generalization and instantiation for identifiers
  * Use TypeSchemes inside the typed AST
  * Prepare TypeScheme
  * Refactoring
  * Apply substitutions to the environment
  * Use log crate
  * Move identifiers to Environment
  * Move function signature
  * Division
  * Hacky new DType implementation
  * Initial work on function definitions
  * Remove variadic functions
  * Some changes w.r.t lists
  * Re-enable some tests
  * First set of constraints, disable failing tests
  * Remove Never, initial constraints
  * Add environment, name generator, qualified types, type schemes
  * Basic error handling
  * Move over code from type inference experiments
  * Move function
  * Reduce public interface of typechecker
  * Clean up includes
  * Split typechecker into multiple modules
  * Add some initial examples
  * Preliminary support for generic lists
  * Add proper type checking for lists
  * Initial support for creating lists
  * Show quotes for pretty-printed strings
* Mon Jun 17 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.12.0
  * Add support for struct/record types (see documentation)
  * Extended number formatting
  * Function decorators
  * Added random function
  * Random distribution sampling
  * Add NaN, inf, is_nan and is_infinite
  * Add function to solve quadratic equations
  * Add element(…) function for retrieving properties of chemical elements
  * Implement 'Never' type (!)
  * Fix callables in binary operators
  * Add jansky and solar flux unit
  * Add "darcy" unit
  * Add yuan as renminbi alias
  * Add permille unit
  * Tokenize three periods as ellipsis (not just unicode character …)
  * style: status badge for CICD in README.md
  * Do some minor cleanup in parser.rs
  * feat: nicer error messages during development
  * Bump iana-time-zone to no longer use a yanked package
  * Fix formatting issue in list-functions.md
  * Fix clippy lints
  * Proper subtyping rules for Never type
* Thu Mar 21 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.11.0
  * Don't autocomplete opening paren after function call that follows //
  * Enhance the help command to print info about a given unit
  * Allow let definitions to have decorators
  * Add metadata to physics/constants.nbt
  * Parser: disallow aliases decorators on let statements to have prefix info
  * Rename "help <keyword>" command to "info"
  * Tweak how units are formatted in the `info` command
  * Introduce DType::is_scalar function
  * Special case scalar values in the info command
  * Cleanup info <variable> output
  * Add integration tests for new info command
  * Add support for the info command into numbat-wasm
  * Add U+2126 OHM SIGN as a short alias for the `ohm` unit
  * Wait for background currency fetch thread to finish before exiting
  * Only prefetch currency info when using the interactive repl
  * Unflatten the Config/MainConfig struct
  * WIP:  Initial support for DateTime types
  * Apply review suggestions
  * Add new datetime functions and related tests
  * Add tentative impl for timezone conversion
  * Better TypeErrors when dealing with DateTimes
  * Add tab-completion for timezones
  * Update numbat-wasm/Cargo.lock
  * Include "local" in the list of all timezones for completion
  * Move datetime functions out of core and into their own module
  * Replace a bool flag in BinaryOperatorForDate with an enum with more meaningful names
  * Replace a panic with an unreachable
  * Throw a runtime error if the provided timezone is unknown
  * Minor things for datetime handling
  * In the tabcompletion code for timezones, recognize other conversion operators
  * Remove Expression::DateTime from the AST as this wasn't actually used/needed
  * Fix string interpolation for datetimes
  * Update/clarify comments
  * Further small fixups, from codereview
  * Switch to a new "subsec_nanos" function from chrono
  * Allow tz conversion using any string type
  * Add #[track_caller] annotation to some panicy VM functions
  * Add "UTC" variable
  * Numbat PPA for Ubuntu and derivatives
  * Add info about architecture for PPA and AUR
  * Add only existing modules to imported_modules list
  * Enable using both script and expression cli arguments
  * Remove explicit 'ControlFlow::Break(ExitStatus::Succes)' case.
  * Add '-i' option to enter interactive session after executing script or expression
  * Skip serializing 'enter_repl'
  * Update .lock file
  * Add Rydberg constant
  * Only show suggestions for really simple factors
  * Show readable type in incompatible dim. errors
  * Set upper break for scientific notation to 6
  * Web: Add HTML formatter
  * Add build script
  * Invert order of 'could not be infered' errors
  * Proper error for wrong non-dtype argument
  * Hide some options in short -h text
  * Fix wasm version
  * Add meta data for mathematical constants
  * More complete @name/@url annotations for constants
  * Add newline for info <unit>
  * Add indentation for WASM version
  * Add documentation
  * Encode '(' and ')' in URLs
  * Formatting
  * Add CODATA 2018 values of physics constants
  * Add U+3BC variants of greek mu
  * Minor improvement in comments
  * Improve binomial coeffient example using logical operators
  * Improve 'booleans' example
  * Update syntax example to include logical operators
  * Add logical ops to operator precedence table
  * Fix markdown for logical 'or'
  * Unicode input feature
  * Avoid poisoned Lazy instance by moving potential panic outside
  * Update CI file
  * Fix path to modules/ directory for tests
  * Disable windows x86_64 build
  * Add basic hex conversion
  * Use 'inspect'ion tool to auto-generate list of units
  * Remove NPM/Node dependency
  * Add wasm stage
  * Make attohttpc dependency optional, shrink WASM size from 1.3 MiB to 800 KiB
  * Re-enable WASM tests
  * Initial version of blog post
  * Updates
  * Section on types
  * Update
  * More updates
  * Add og metadata
  * Add .htaccess
  * Minor update
  * Minor updates
  * Restore prelude
  * Remove build-pkg script
  * Re-enable x86_64 Windows CI build
  * Remove noopener, noreferrer
  * Combine both accepts_prefix conditions into one
  * Also use correct prefix for derived units
  * Do not allow short prefixes for 'year'
  * Meta-data for light second
  * Remove DateOperationResult
  * Remove TODO
  * Add ability to hide 'private' functions and variables
  * Full simplify before function calls
  * Human-readable time durations
  * Use local timezone, not local UTC offset
  * parse_datetime: relaxed formats
  * Add timezone parsing
  * Add documentation for datetime handling
  * Use tropical years as 'year' unit
  * Update to mdbook v0.4.37
  * Date and time documentation updates
  * Add 'bin' and 'oct', closes #289
  * Fix clippy suggestions
  * Fix formatting
  * Initial work on function types
  * First working version!
  * Minor updates
  * Initial type checks for function references
  * Allow FFI targets in function references, conversion functions
  * Better implementation of base conversion functions
  * Add proper parser errors
  * Resolve TODOs, better errors
  * Resolve TODOs
  * Add typechecker tests
  * Allow f()() syntax
  * Rename to_celsius/to_fahrenheit
  * Re-enable suggestions for function names
  * Rename
  * Add page about conversion functions
  * Formatting
  * Embed timezone conversion into conversion-function framework
  * Conversion function clarifications
  * Rename parse_datetime => datetime
  * Bump numbat-exchange-rates version
  * White background for Numbat icon
  * Add outline for icon
  * Remove outdated logo files
  * Fix str_replace implementation
  * Add `date` and `today`
  * Add 'time' function
  * Do not add opening paren when completing conversion functions
  * Always embed modules
  * Move HtmlFormatter to core
  * Format datetime values using datetime(…) function
  * Make to_markup more flexible
  * Store datetimes with fixed offset
  * Runtime error for wrong format specifiers
  * Add tests for datetime runtime errors, fix RFC2822 panic
  * Always return specified offset/tz from datetime(…)
  * Update book/src/cli-installation.md
  * Minor installation page fixes
  * Improve documentation around ad-hoc units
  * Disallow dimensionless base units
  * Add imperial volume units
  * Move the create_dir_all call to get_history_path
  * Add CanonicalName struct
  * Use CanonicalName struct on UnitIdentifier
  * Use correct AcceptsPrefix for units on bytecode_interpreter
  * Fix pretty printing long units with long prefixes
  * Change Unit#new_base to receive CanonicalName
  * make link in GitHub Corner open in a new tab
  * refactor: remove div's deprecated align attribute (#311)
  * refactor: remove unnecessary borrows
  * refactor: remove unnecessary type conversions
  * refactor: remove unnecessary calls to `format!`
  * refactor: remove unnecessary `.clone()` calls
  * refactor: replace strings with single characters
  * style: simplify string search in src/completer.rs
  * refactor: remove unnecessary `to_string` calls
  * refactor: remove reference that's unnecessary
  * refactor: wrap result of `cmp` for `PartialOrd`
  * refactor: remove manual impl. of `Option::map`
  * refactor: readability improvement with `is_empty`
  * feat: create prerequisite directories for history if they don't exist, already
  * Correct minor grammar mistake
  * Fix minor typo
  * Don't hide `--no-config` flag
  * Support subscript characters in identifiers
  * Add some units
  * Bump dependencies
  * Use default allocator instead of wee_alloc in numbat-wasm
  * Add desktop file and Numbat icons to assets
  * Recommend installing desktop files and icons when relevant
  * Improve unterminated string interpolation error
  * Minor capitalization fixes
  * Add Chimera Linux installation instructions
  * Add SVG icon and more PNG icon sizes to assets
  * Includes icons and desktop file in build artifacts
  * Make the trailing errors skip all characters until the end of the lines to avoid throwing duplicated errors for the same character
  * tokenize the logical operators
  * Add the parser and interpreter without tests
  * add parser tests
  * fix typechecking bug and improve error message
  * add interpreter tests on the error messages
  * simplify binop parsing
  * Added the ThermalTransmittance dimension
  * Change parse error to unterminated string
  * Add misc unit: ampere-hours
* Sat Nov 18 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Initial package for numbat 1.8.0
